==> nextcloud-25.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/bg.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Визуализатор",
    "Simple file viewer with slideshow for media" : "Прост визуализатор на файлове със слайдшоу за медии",
    "Your browser does not support audio." : "Вашият браузър не поддържа аудио.",
    "Error loading {name}" : "Грешка при зареждането на {name}",
    "Image saved" : "Изображението е записано",
    "Unsaved changes" : "Незаписани промени",
    "Drop changes" : "Игнориране на промените",
    "Your browser does not support videos." : "Вашият браузър не поддържа видеоклипове.",
    "Edit" : "Редактиране",
    "Open sidebar" : "Отвори страничното меню",
    "Download" : "Изтегляне",
    "Delete" : "Изтриване",
    "There is no plugin available to display this file type" : "Няма налична добавка за показване на този тип файл",
    "View" : "Изглед",
    "Name" : "Име",
    "Save" : "Запиши",
    "Save as" : "Запиши като",
    "Back" : "Назад",
    "Loading …" : "Зареждане …",
    "Reset" : "Възстановяване",
    "All changes will be lost." : "Всички промени ще бъдат загубени.",
    "Are you sure you want to continue?" : "Сигурни ли сте, че искате да продължите?",
    "Cancel" : "Отказ",
    "Continue" : "Продължаване",
    "Undo" : "Отмяна",
    "Redo" : "Повторение",
    "Show original image" : "Показване на оригиналното изображение",
    "Zoom in" : "Увеличаване на мащаба",
    "Zoom out" : "Намаляване на мащаба",
    "Toggle zoom menu" : "Превключване на менюто за мащабиране",
    "Adjust" : "Настройване",
    "Fine-tune" : "Фина настройка",
    "Filters" : "Филтри",
    "Watermark" : "Воден знак",
    "Draw" : " Рисуване /Чертане/",
    "Resize" : "Преоразмеряване",
    "Invalid image." : "Невалидно изображение.",
    "Error while uploading the image." : "Грешка при качване на изображението.",
    "are not images" : "не са изображения",
    "is not an image" : "не е изображение",
    "to be uploaded" : "да бъдат качени",
    "Crop" : "Изрязване",
    "Original" : "Оригинал",
    "Custom" : "Персонализиран",
    "Square" : "Квадрат",
    "Landscape" : "Пейзаж",
    "Portrait" : "Портрет",
    "Ellipse" : "Елипса",
    "Classic TV" : "Класическа ТВ",
    "CinemaScope" : "КиноЕкран",
    "Arrow" : "Стрелка",
    "Blur" : "Замъгляване",
    "Brightness" : "Яркост",
    "Contrast" : "Контраст",
    "Un-flip X" : "Отмяна на Х обръщане",
    "Flip X" : "Х Обръщане",
    "Un-flip Y" : "Отмяна на Y обръщане",
    "Flip Y" : "Y Обръщане",
    "HSV" : "HSV",
    "Hue" : "Нюанс",
    "Saturation" : "Насищане",
    "Value" : "Стойност",
    "Image" : "Изображение",
    "Importing …" : "Импортиране.../внасяне/",
    "+ Add image" : "+ Добавяне на изображение",
    "Line" : "Линия",
    "Pen" : "Химилка",
    "Polygon" : "Многоъгълник",
    "Sides" : "Страни",
    "Rectangle" : "Правоъгълник",
    "Corner Radius" : "Радиус на ъгъла",
    "Width in pixels" : "Ширина в пиксели",
    "Height in pixels" : "Височина в пиксели",
    "Toggle ratio lock" : "Превключване на заключване на съотношението",
    "Reset to original image size" : "Възстановяване на оригиналния размер на изображението",
    "Rotate" : "Завъртане",
    "Text" : "Текст",
    "Text spacing" : "Разредка на текста",
    "Text alignment" : "Подравняване на текст",
    "Font family" : "Семейство шрифтове",
    "Size" : "Размер",
    "Letter spacing" : "Разстояние между буквите",
    "Line height" : "Височина на линията",
    "Warmth" : "Топлина",
    "+ Add watermark" : "+ Добавяне на воден знак",
    "Choose watermark type" : "Избор на тип воден знак",
    "Upload watermark" : "Качване на воден знак",
    "Add as text" : "Добавяне като текст",
    "Padding" : "Уплътняване",
    "Shadow" : "Сянка",
    "Horizontal" : "Хоризонтално",
    "Vertical" : "Вертикално",
    "Opacity" : "Непрозрачност",
    "Position" : "Позиция",
    "Stroke" : "Щрих, линия",
    "Save image as" : "Запазване на изображението като",
    "Extension" : "Разширение",
    "Name is required." : "Името е задължително/нужно/.",
    "Quality" : "Качество ",
    "Saved image size (width x height)" : "Размер на запазеното изображение (ширина x височина)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Обърнете внимание, че избраната област за изрязване е по-ниска от приложеното преоразмеряване, което може да доведе до влошаване на качеството",
    "Actual size (100%)" : "Действителен размер (100%)",
    "Fit size" : "Подходящ размер",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Покажете най-новите си празнични снимки и видеоклипове, като във филмите, покажете част от най-новия си роман директно от вашия nextcloud, изберете най-добрия GIF от колекцията си благодарение на директния преглед на любими за вас файлове и много други!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/bg.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Визуализатор",
    "Simple file viewer with slideshow for media" : "Прост визуализатор на файлове със слайдшоу за медии",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Покажете най-новите си ваканционни снимки и видеоклипове като във филмите, покажете част от най-новия си роман директно от вашия nextcloud, изберете най-добрия GIF от колекцията си благодарение на директния преглед на любими за вас файлове и много други!",
    "Your browser does not support audio." : "Вашият браузър не поддържа аудио.",
    "Error loading {name}" : "Грешка при зареждането на {name}",
    "Image saved" : "Изображението е записано",
    "Error saving image" : "Грешка при запазване на изображение",
    "Unsaved changes" : "Незаписани промени",
    "Drop changes" : "Игнориране на промените",
    "Your browser does not support videos." : "Вашият браузър не поддържа видеоклипове.",
    "This file no longer exists" : "Този файл вече не съществува",
    "There is no plugin available to display this file type" : "Няма налична добавка за показване на този тип файл",
    "Edit" : "Редактиране",
    "Open sidebar" : "Отвори страничното меню",
    "Download" : "Изтегляне",
    "Delete" : "Изтриване",
    "View" : "Изглед",
    "Name" : "Име",
    "Save" : "Запиши",
    "Save as" : "Запиши като",
    "Back" : "Назад",
    "Loading …" : "Зареждане …",
    "Reset" : "Възстановяване",
    "All changes will be lost." : "Всички промени ще бъдат загубени.",
    "Are you sure you want to continue?" : "Сигурни ли сте, че искате да продължите?",
    "Cancel" : "Отказ",
    "Apply" : "Приложи",
    "Warning" : "Внимание",
    "Confirm" : "Потвърдете",
    "Undo" : "Отмяна",
    "Redo" : "Повторение",
    "Show original image" : "Показване на оригиналното изображение",
    "Zoom in" : "Увеличаване на мащаба",
    "Zoom out" : "Намаляване на мащаба",
    "Toggle zoom menu" : "Превключване на менюто за мащабиране",
    "Adjust" : "Настройване",
    "Fine-tune" : "Фина настройка",
    "Filters" : "Филтри",
    "Watermark" : "Воден знак",
    "Draw" : " Рисуване /Чертане/",
    "Resize" : "Преоразмеряване",
    "Invalid image." : "Невалидно изображение.",
    "Error while uploading the image." : "Грешка при качване на изображението.",
    "are not images" : "не са изображения",
    "is not an image" : "не е изображение",
    "to be uploaded" : "да бъдат качени",
    "Crop" : "Изрязване",
    "Original" : "Оригинал",
    "Custom" : "Персонализиран",
    "Square" : "Квадрат",
    "Landscape" : "Пейзаж",
    "Portrait" : "Портрет",
    "Ellipse" : "Елипса",
    "Classic TV" : "Класическа ТВ",
    "CinemaScope" : "КиноЕкран",
    "Arrow" : "Стрелка",
    "Blur" : "Замъгляване",
    "Brightness" : "Яркост",
    "Contrast" : "Контраст",
    "Un-flip X" : "Отмяна на Х обръщане",
    "Flip X" : "Х Обръщане",
    "Un-flip Y" : "Отмяна на Y обръщане",
    "Flip Y" : "Y Обръщане",
    "HSV" : "HSV",
    "Hue" : "Нюанс",
    "Saturation" : "Насищане",
    "Value" : "Стойност",
    "Image" : "Изображение",
    "Importing …" : "Импортиране.../внасяне/",
    "+ Add image" : "+ Добавяне на изображение",
    "Line" : "Линия",
    "Pen" : "Химилка",
    "Polygon" : "Многоъгълник",
    "Sides" : "Страни",
    "Rectangle" : "Правоъгълник",
    "Corner Radius" : "Радиус на ъгъла",
    "Width in pixels" : "Ширина в пиксели",
    "Height in pixels" : "Височина в пиксели",
    "Toggle ratio lock" : "Превключване на заключване на съотношението",
    "Reset to original image size" : "Възстановяване на оригиналния размер на изображението",
    "Rotate" : "Завъртане",
    "Text" : "Текст",
    "Text spacing" : "Разредка на текста",
    "Text alignment" : "Подравняване на текст",
    "Font family" : "Семейство шрифтове",
    "Size" : "Размер",
    "Letter spacing" : "Разстояние между буквите",
    "Line height" : "Височина на линията",
    "Warmth" : "Топлина",
    "+ Add watermark" : "+ Добавяне на воден знак",
    "Choose watermark type" : "Избор на тип воден знак",
    "Upload watermark" : "Качване на воден знак",
    "Add as text" : "Добавяне като текст",
    "Padding" : "Уплътняване",
    "Shadow" : "Сянка",
    "Horizontal" : "Хоризонтално",
    "Vertical" : "Вертикално",
    "Opacity" : "Непрозрачност",
    "Position" : "Позиция",
    "Stroke" : "Щрих, линия",
    "Save image as" : "Запазване на изображението като",
    "Extension" : "Разширение",
    "Name is required." : "Името е задължително/нужно/.",
    "Quality" : "Качество ",
    "Saved image size (width x height)" : "Размер на запазеното изображение (ширина x височина)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Обърнете внимание, че избраната област за изрязване е по-ниска от приложеното преоразмеряване, което може да доведе до влошаване на качеството",
    "Actual size (100%)" : "Действителен размер (100%)",
    "Fit size" : "Подходящ размер",
    "Menu" : "Меню",
    "Height" : "Ръст"
},
"nplurals=2; plural=(n != 1);");
